"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _chalk = require("chalk");

var _toolkit = require("@aragon/toolkit");

var _web3Fallback = require("../../helpers/web3-fallback");

//
const command = 'grant [grantees..]';
exports.command = command;
const describe = 'Grant an address permission to create new versions in this package';
exports.describe = describe;

const builder = function (yargs) {
  return yargs.positional('grantees', {
    description: 'The address being granted the permission to publish to the repo',
    array: true,
    default: []
  });
};

exports.builder = builder;

const handler = async function ({
  // Globals
  reporter,
  gasPrice,
  network,
  module,
  apm: apmOptions,
  // Arguments
  grantees
}) {
  const web3 = await (0, _web3Fallback.ensureWeb3)(network);

  const progressHandler = (step, data) => {
    switch (step) {
      case 1:
        reporter.info(`Fetching repository`);
        break;

      case 2:
        // eslint-disable-next-line no-case-declarations
        const address = data;
        reporter.info(`Granting permission to publish on ${(0, _chalk.blue)(module.appName)} for ${address}`);
        break;

      case 3:
        // eslint-disable-next-line no-case-declarations
        const txHash = data;
        reporter.success(`Successful transaction (${(0, _chalk.blue)(txHash)})`);
        break;
    }
  };

  await (0, _toolkit.grantNewVersionsPermission)(web3, module.appName, apmOptions, grantees, progressHandler, {
    gasPrice: gasPrice || network.gasPrice
  });
};

exports.handler = handler;
//# sourceMappingURL=grant.js.map