"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _chalk = require("chalk");

var _toolkit = require("@aragon/toolkit");

var _web3Fallback = require("../../helpers/web3-fallback");

//
const command = 'info <apmRepo> [apmRepoVersion]';
exports.command = command;
const describe = 'Get information about a package';
exports.describe = describe;

const builder = yargs => {
  return yargs.option('apmRepo', {
    describe: 'Name of the aragonPM repo'
  }).option('apmRepoVersion', {
    describe: 'Version of the package upgrading to',
    default: 'latest'
  });
};

exports.builder = builder;

const handler = async function ({
  apmRepo,
  apmRepoVersion,
  apm: apmOptions,
  network
}) {
  const web3 = await (0, _web3Fallback.ensureWeb3)(network);
  const apmRepoName = (0, _toolkit.defaultAPMName)(apmRepo);

  const progressHandler = step => {
    switch (step) {
      case 1:
        console.log(`Initialize aragonPM`);
        break;

      case 2:
        // TODO: Use reporter instead of chalk? Should reporter have a 'title' function?
        console.log(`Fetching ${(0, _chalk.bold)(apmRepo)}@${apmRepoVersion}`);
        break;
    }
  };

  const apmRepoObject = await (0, _toolkit.getApmRepo)(web3, apmRepoName, apmOptions, apmRepoVersion, progressHandler); // TODO: Improve parsing of abi and env to display useful information

  delete apmRepoObject.abi;
  delete apmRepoObject.environments;
  const apmRepoJSON = JSON.stringify(apmRepoObject, null, 2);
  console.log('\n', apmRepoJSON);
};

exports.handler = handler;
//# sourceMappingURL=info.js.map