"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _cliTable = _interopRequireDefault(require("cli-table"));

var _listr = _interopRequireDefault(require("listr"));

var _toolkit = require("@aragon/toolkit");

var _web3Fallback = require("../../helpers/web3-fallback");

var _web = _interopRequireDefault(require("web3"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'packages [apmRegistry]';
exports.command = command;
const describe = 'List all packages in the registry';
exports.describe = describe;

const builder = function (yargs) {
  return yargs.option('apmRegistry', {
    description: 'The registry to inspect',
    type: 'string',
    default: 'aragonpm.eth'
  });
};

exports.builder = builder;

const handler = async function ({
  apmRegistry,
  network,
  apm: apmOptions,
  wsProvider
}) {
  const web3 = wsProvider ? new _web.default(wsProvider) : await (0, _web3Fallback.ensureWeb3)(network);
  let packages;
  const tasks = new _listr.default([{
    title: `Fetching APM packages for ${apmRegistry}`,
    task: async (ctx, task) => {
      task.output = `Initializing APM`;

      const progressHandler = step => {
        switch (step) {
          case 1:
            task.output = `Fetching APM Registry`;
            break;

          case 2:
            task.output = `Gathering packages in registry`;
            break;
        }
      };

      packages = await (0, _toolkit.getApmRegistryPackages)(web3, apmRegistry, apmOptions, progressHandler);
    }
  }]);
  await tasks.run();
  displayPackages(packages);
};
/**
 * Display packages and their version in a table
 *
 * @param {Object[]} packages Packages
 * @returns {void}
 */


exports.handler = handler;

function displayPackages(packages) {
  const table = new _cliTable.default({
    head: ['App', 'Repo Address']
  });
  packages.forEach(aPackage => {
    const row = [aPackage.name, aPackage.repo];
    table.push(row);
  });
  console.log('\n', table.toString());
}
//# sourceMappingURL=packages.js.map