"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.task = exports.args = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../../../helpers/listr-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const LATEST_VERSION = 'latest';

const args = function (yargs) {
  return yargs.option('apmRepo', {
    describe: 'Name of the aragonPM repo'
  }).option('apmRepoVersion', {
    describe: 'Version of the package upgrading to',
    default: 'latest'
  });
};

exports.args = args;

const task = async ({
  apm,
  apmRepo,
  apmRepoVersion = LATEST_VERSION,
  artifactRequired = true,
  silent,
  debug
}) => {
  return new _listr.default([{
    title: 'Get Repo',
    task: async ctx => {
      if (apmRepoVersion === LATEST_VERSION) {
        ctx.repo = await apm.getLatestVersion(apmRepo, _toolkit.DEFAULT_IPFS_TIMEOUT);
      } else {
        ctx.repo = await apm.getVersion(apmRepo, apmRepoVersion.split('.'), _toolkit.DEFAULT_IPFS_TIMEOUT);
      } // appId is loaded from artifact.json in IPFS


      if (artifactRequired && !ctx.repo.appId) {
        // TODO: load ipfs aragon node and fetch repo again. If this time we have the artifact then return otherwise throw Error.
        throw new Error('Cannot find artifacts in aragonPM repo. Please make sure the package is published and IPFS or your HTTP server running.');
      }
    }
  }], (0, _listrOptions.default)(silent, debug));
};

exports.task = task;
//# sourceMappingURL=getRepoTask.js.map