"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = runPublishTask;

var _listr = _interopRequireDefault(require("listr"));

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../../../helpers/listr-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
async function runPublishTask({
  // Globals
  gasPrice,
  web3,
  module,
  http,
  provider,
  apm: apmOptions,
  silent,
  debug,
  // Arguments
  /// Conditionals
  onlyArtifacts,
  /// Context
  version,
  pathToPublish,
  contractAddress
}) {
  const appName = module.appName;
  return new _listr.default([{
    title: `Publish ${appName}`,
    enabled: () => !onlyArtifacts,
    task: async (ctx, task) => {
      ctx.contractInstance = null; // clean up deploy sub-command artifacts

      task.output = 'Generating transaction and waiting for confirmation';
      const accounts = await web3.eth.getAccounts();
      const from = accounts[0];
      const transaction = await (0, _toolkit.apmPublishVersion)(web3, from, appName, version, http ? 'http' : provider, http || pathToPublish, contractAddress, from, apmOptions);
      transaction.from = from;
      transaction.gasPrice = gasPrice; // apm.js already calculates the recommended gas

      ctx.receipt = await web3.eth.sendTransaction(transaction);
    }
  }], (0, _listrOptions.default)(silent, debug));
}
//# sourceMappingURL=runPublishTask.js.map