"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _chalk = require("chalk");

var _listr = _interopRequireDefault(require("listr"));

var _toolkit = require("@aragon/toolkit");

var _web3Fallback = require("../../helpers/web3-fallback");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'versions [apmRepo]';
exports.command = command;
const describe = 'Shows all the previously published versions of a given repository';
exports.describe = describe;

const builder = function (yargs) {
  return yargs.option('apmRepo', {
    description: 'Name of the APM repository',
    type: 'string',
    default: null
  });
};

exports.builder = builder;

const handler = async function ({
  reporter,
  apmRepo,
  module,
  network,
  apm: apmOptions
}) {
  let versions, apmRepoName;
  const tasks = new _listr.default([{
    title: 'Fetching published versions',
    task: async (ctx, task) => {
      const web3 = await (0, _web3Fallback.ensureWeb3)(network);
      apmRepoName = apmRepo ? (0, _toolkit.defaultAPMName)(apmRepo) : module.appName;
      task.title = `Fetching ${(0, _chalk.bold)(apmRepoName)} published versions`;
      versions = await (0, _toolkit.getApmRepoVersions)(web3, apmRepoName, apmOptions);
    }
  }]);
  await tasks.run();
  reporter.newLine();
  displayVersionNumbers(apmRepoName, versions, reporter);
  displayVersions(versions, reporter);
};
/**
 * Display the number of published versions for the repository
 * @param {string} apmRepoName Repo name
 * @param {Object[]} versions Repo versions
 * @param {Object} reporter Reporter
 * @returns {void}
 */


exports.handler = handler;

function displayVersionNumbers(apmRepoName, versions, reporter) {
  reporter.info(`${(0, _chalk.blue)(apmRepoName)} has ${(0, _chalk.green)(versions.length)} published versions`);
}
/**
 * Display the published versions for a repository
 * @param {Object[]} versions Repo versions
 * @param {Object} reporter Reporter
 * @returns {void}
 */


function displayVersions(versions, reporter) {
  versions.map(version => {
    if (version && version.content) {
      reporter.success(`${(0, _chalk.blue)(version.version)}: ${version.contractAddress} ${version.content.provider}:${version.content.location}`);
    } else if (version && version.error) {
      reporter.warning(`${(0, _chalk.blue)(version.version)}: ${version.contractAddress} ${version.error}`);
    } else {
      reporter.error(`${(0, _chalk.blue)(version.version)}: ${version.contractAddress} Version not found in provider`);
    }
  });
}
//# sourceMappingURL=versions.js.map