"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _toolkit = require("@aragon/toolkit");

var _daoArg = _interopRequireDefault(require("../utils/daoArg"));

var _aclExecHandler = _interopRequireDefault(require("./utils/aclExecHandler"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
// Note: we usually order these values as entity, proxy, role but this order fits
//       better with other CLI commands
const command = 'grant <dao> <app> <role> <entity> [params...]';
exports.command = command;
const describe = 'Grant a permission in a DAO (only permission manager can do it)';
exports.describe = describe;

const builder = function (yargs) {
  return (0, _daoArg.default)(yargs).positional('params', {
    description: 'ACL parameters',
    default: []
  });
};

exports.builder = builder;

const handler = async function ({
  reporter,
  dao,
  app,
  role,
  entity,
  network,
  wsProvider,
  apm,
  gasPrice,
  params
}) {
  const method = params.length === 0 ? 'grantPermission' : 'grantPermissionP';
  const methodParams = params.length === 0 ? [entity, app, role] : [entity, app, role, params.map(_toolkit.convertStringToParam).map(_toolkit.encodeParam)];
  return (0, _aclExecHandler.default)(dao, method, methodParams, {
    reporter,
    gasPrice,
    apm,
    network,
    wsProvider,
    role
  });
};

exports.handler = handler;
//# sourceMappingURL=grant.js.map