"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _chalk = require("chalk");

var _toolkit = require("@aragon/toolkit");

var _web3Fallback = require("../../helpers/web3-fallback");

var _execHandler = require("./utils/execHandler");

var _util = require("../../util");

//
const command = 'act <agent-address> <target> [signature] [call-args..]';
exports.command = command;
const describe = 'Executes an action from the Agent app';
exports.describe = describe;

const builder = function (yargs) {
  return yargs.positional('agent-address', {
    description: 'Address of the Agent app proxy',
    type: 'string'
  }).positional('target', {
    description: 'Address where the action is being executed',
    type: 'string'
  }).option('signature', {
    description: 'Signature of the function to be executed (e.g. "myMethod(uint256,string)"',
    type: 'string'
  }).option('call-args', {
    description: 'Arguments to be passed to the function',
    array: true,
    default: []
  }).option('call-data', {
    description: 'Raw call data',
    type: 'string',
    default: '0x'
  }).option('eth-value', {
    description: 'Amount of ETH from the contract that is sent with the action',
    default: '0'
  });
};

exports.builder = builder;

const handler = async function ({
  reporter,
  apm,
  network,
  agentAddress,
  target,
  signature,
  callArgs,
  callData,
  ethValue,
  gasPrice,
  wsProvider
}) {
  const web3 = await (0, _web3Fallback.ensureWeb3)(network);
  const dao = await (0, _toolkit.getAppKernel)(web3, agentAddress);
  const encodedCallData = signature ? (0, _toolkit.encodeActCall)(signature, callArgs.map(_util.parseArgumentStringIfPossible)) : callData;
  reporter.debug('Encoded call data: ', encodedCallData);
  const task = await (0, _execHandler.task)({
    dao,
    app: agentAddress,
    method: _toolkit.EXECUTE_FUNCTION_NAME,
    params: [target, web3.utils.toWei(ethValue), encodedCallData],
    reporter,
    apm,
    network,
    gasPrice,
    wsProvider,
    web3
  });
  const {
    transactionPath
  } = await task.run();
  reporter.newLine();
  reporter.success(`Successfully executed: "${(0, _chalk.blue)(transactionPath.description)}"`);
};

exports.handler = handler;
//# sourceMappingURL=act.js.map