"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _chalk = require("chalk");

var _web3Fallback = require("../../helpers/web3-fallback");

var _execHandler = require("./utils/execHandler");

var _daoArg = _interopRequireDefault(require("./utils/daoArg"));

var _util = require("../../util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'exec <dao> <proxy-address> <fn> [fn-args..]';
exports.command = command;
const describe = 'Executes a call in an app of a DAO';
exports.describe = describe;

const builder = function (yargs) {
  return (0, _daoArg.default)(yargs).positional('proxy-address', {
    description: 'Proxy address of the app with the function to be run'
  }).positional('fn', {
    description: 'Function to be executed'
  }).option('fn-args', {
    description: 'Arguments to be passed to the function',
    array: true,
    default: []
  });
};

exports.builder = builder;

const handler = async function ({
  reporter,
  dao,
  apm,
  network,
  gasPrice,
  proxyAddress,
  fn,
  fnArgs,
  wsProvider
}) {
  const task = await (0, _execHandler.task)({
    dao,
    app: proxyAddress,
    method: fn,
    params: fnArgs.map(_util.parseArgumentStringIfPossible),
    reporter,
    gasPrice,
    apm,
    network,
    wsProvider,
    web3: await (0, _web3Fallback.ensureWeb3)(network)
  });
  const {
    transactionPath
  } = await task.run();
  reporter.newLine();
  reporter.success(`Successfully executed: "${(0, _chalk.blue)(transactionPath.description)}"`);
};

exports.handler = handler;
//# sourceMappingURL=exec.js.map