"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _chalk = require("chalk");

var _toolkit = require("@aragon/toolkit");

var _web3Fallback = require("../../helpers/web3-fallback");

var _listrOptions = _interopRequireDefault(require("../../helpers/listr-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
// dao id assign command
const idAssignCommand = 'assign <dao> <aragon-id>';
const idAssignDescribe = 'Assign an Aragon Id to a DAO address';

const idAssignBuilder = yargs => {
  return yargs.positional('dao', {
    description: 'DAO address',
    type: 'string'
  }).positional('aragon-id', {
    description: 'Aragon Id',
    type: 'string'
  });
}; // dao id shortcut


const command = 'id <dao> <aragon-id>';
exports.command = command;
const describe = 'Shortcut for `dao id assign`';
exports.describe = describe;

const builder = yargs => {
  return idAssignBuilder(yargs).command(idAssignCommand, idAssignDescribe, idAssignBuilder, exports.handler);
};

exports.builder = builder;

const handler = async function ({
  aragonId,
  reporter,
  network,
  apm: apmOptions,
  dao,
  gasPrice,
  silent,
  debug
}) {
  const web3 = await (0, _web3Fallback.ensureWeb3)(network);
  const options = {
    web3,
    ensRegistry: apmOptions.ensRegistryAddress
  };
  const tasks = new _listr.default([{
    title: 'Validating Id',
    task: async () => {
      if (await (0, _toolkit.isIdAssigned)(aragonId, options)) {
        throw Error(`${aragonId} is already assigned.`);
      }
    }
  }, {
    title: 'Assigning Id',
    task: async () => (0, _toolkit.assignId)(dao, aragonId, { ...options,
      gasPrice
    })
  }], (0, _listrOptions.default)(silent, debug));
  await tasks.run();
  reporter.newLine();
  reporter.success(`${(0, _chalk.green)(aragonId)} successfully assigned to ${dao}`);
};

exports.handler = handler;
//# sourceMappingURL=id-assign.js.map