"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.task = exports.builder = exports.describe = exports.command = exports.BARE_TEMPLATE_DEPLOY_EVENT = exports.BARE_INSTANCE_FUNCTION = exports.BARE_TEMPLATE = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _chalk = require("chalk");

var _toolkit = require("@aragon/toolkit");

var _web3Fallback = require("../../helpers/web3-fallback");

var _listrOptions = _interopRequireDefault(require("../../helpers/listr-options"));

var _util = require("../../util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const BARE_TEMPLATE = (0, _toolkit.defaultAPMName)('bare-template');
exports.BARE_TEMPLATE = BARE_TEMPLATE;
const BARE_INSTANCE_FUNCTION = 'newInstance';
exports.BARE_INSTANCE_FUNCTION = BARE_INSTANCE_FUNCTION;
const BARE_TEMPLATE_DEPLOY_EVENT = 'DeployDao';
exports.BARE_TEMPLATE_DEPLOY_EVENT = BARE_TEMPLATE_DEPLOY_EVENT;
const command = 'new [template] [template-version]';
exports.command = command;
const describe = 'Create a new DAO';
exports.describe = describe;

const builder = yargs => {
  return yargs.positional('template', {
    description: 'Name of the template to use creating the DAO',
    default: exports.BARE_TEMPLATE
  }).positional('template-version', {
    description: 'Version of the template to be used',
    default: 'latest'
  }).option('fn-args', {
    description: 'Arguments to be passed to the newInstance function (or the function passed with --fn)',
    array: true,
    default: [],
    coerce: args => {
      return args.map(_util.parseArgumentStringIfPossible);
    }
  }).option('fn', {
    description: 'Function to be called to create instance',
    default: exports.BARE_INSTANCE_FUNCTION
  }).option('deploy-event', {
    description: 'Event name that the template will fire on success',
    default: exports.BARE_TEMPLATE_DEPLOY_EVENT
  }).option('aragon-id', {
    description: 'Assign an Aragon Id to the DAO',
    type: 'string'
  });
}; // Task will be moved to handler once `dao start` is refactored


exports.builder = builder;

const task = async ({
  web3,
  gasPrice,
  apmOptions,
  template,
  templateVersion,
  fn,
  fnArgs,
  deployEvent,
  templateInstance,
  silent,
  debug,
  aragonId
}) => {
  template = (0, _toolkit.defaultAPMName)(template);
  let repo, daoAddress;
  const tasks = new _listr.default([{
    title: 'Start IPFS',
    skip: async () => (0, _toolkit.isLocalDaemonRunning)(),
    task: async () => {
      await (0, _toolkit.startLocalDaemon)((0, _toolkit.getBinaryPath)(), (0, _toolkit.getDefaultRepoPath)(), {
        detached: false
      });
    }
  }, {
    title: `Fetching template ${(0, _chalk.bold)(template)}@${templateVersion}`,
    task: async () => {
      repo = await (0, _toolkit.getApmRepo)(web3, template, apmOptions, templateVersion);
    },
    enabled: () => !templateInstance
  }, {
    title: 'Create new DAO from template',
    task: async ctx => {
      daoAddress = await (0, _toolkit.newDao)({
        repo,
        web3,
        templateInstance,
        newInstanceMethod: fn,
        newInstanceArgs: fnArgs,
        deployEvent,
        gasPrice
      });
      ctx.daoAddress = daoAddress;
    }
  }, {
    title: 'Assigning Aragon Id',
    enabled: () => aragonId,
    task: async () => {
      await (0, _toolkit.assignId)(daoAddress, aragonId, {
        web3,
        ensRegistry: apmOptions.ensRegistryAddress,
        gasPrice
      });
    }
  }], (0, _listrOptions.default)(silent, debug));
  return tasks;
};

exports.task = task;

const handler = async function ({
  reporter,
  network,
  template,
  templateVersion,
  fn,
  fnArgs,
  deployEvent,
  apm: apmOptions,
  aragonId,
  gasPrice,
  silent,
  debug
}) {
  const web3 = await (0, _web3Fallback.ensureWeb3)(network);
  const tasks = await task({
    web3,
    reporter,
    network,
    apmOptions,
    template,
    templateVersion,
    fn,
    fnArgs,
    deployEvent,
    aragonId,
    gasPrice,
    silent,
    debug
  });
  const ctx = await tasks.run();
  reporter.newLine();
  reporter.success(aragonId ? `Created DAO: ${(0, _chalk.green)(aragonId)} at ${(0, _chalk.green)(ctx.daoAddress)}` : `Created DAO: ${(0, _chalk.green)(ctx.daoAddress)}`);
};

exports.handler = handler;
//# sourceMappingURL=new.js.map