"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _chalk = require("chalk");

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../../../helpers/listr-options"));

var _web3Fallback = require("../../../helpers/web3-fallback");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'change-controller <token-address> <new-controller>';
exports.command = command;
const describe = 'Change the controller of a MiniMe token';
exports.describe = describe;

const builder = yargs => {
  return yargs.positional('token-address', {
    description: 'Address of the MiniMe token'
  }).positional('new-controller', {
    description: 'Address of the new controller'
  });
};

exports.builder = builder;

const handler = async function ({
  reporter,
  gasPrice,
  network,
  tokenAddress,
  newController,
  silent,
  debug
}) {
  const web3 = await (0, _web3Fallback.ensureWeb3)(network);
  let txReceipt;
  const tasks = new _listr.default([{
    title: 'Changing the MiniMe token controller',
    task: async () => {
      txReceipt = await (0, _toolkit.changeController)(web3, tokenAddress, newController, gasPrice);
    }
  }], (0, _listrOptions.default)(silent, debug));
  await tasks.run();
  reporter.newLine();
  reporter.success(`Successfully changed the controller of ${(0, _chalk.green)(tokenAddress)} to ${(0, _chalk.green)(newController)}`);
  reporter.info(`Transaction hash: ${(0, _chalk.blue)(txReceipt.transactionHash)}`);
};

exports.handler = handler;
//# sourceMappingURL=change-controller.js.map