"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _chalk = require("chalk");

var _toolkit = require("@aragon/toolkit");

var _web3Fallback = require("../../helpers/web3-fallback");

var _listrOptions = _interopRequireDefault(require("../../helpers/listr-options"));

var _daoArg = _interopRequireDefault(require("./utils/daoArg"));

var _execHandler = require("./utils/execHandler");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'upgrade <dao> <apmRepo> [apmRepoVersion]';
exports.command = command;
const describe = 'Upgrade an app into a DAO';
exports.describe = describe;

const builder = function (yargs) {
  return (0, _daoArg.default)(yargs).option('apmRepo', {
    describe: 'Name of the aragonPM repo'
  }).option('apmRepoVersion', {
    describe: 'Version of the package upgrading to',
    default: 'latest'
  });
};

exports.builder = builder;

const handler = async function ({
  reporter,
  dao,
  gasPrice,
  network,
  wsProvider,
  apm: apmOptions,
  apmRepo,
  apmRepoVersion,
  silent,
  debug
}) {
  const web3 = await (0, _web3Fallback.ensureWeb3)(network);
  const apmRepoName = (0, _toolkit.defaultAPMName)(apmRepo);
  dao = await (0, _toolkit.resolveAddressOrEnsDomain)(dao, web3, apmOptions.ensRegistryAddress);
  const tasks = new _listr.default([{
    title: 'Start IPFS',
    skip: async () => (0, _toolkit.isLocalDaemonRunning)(),
    task: async () => {
      await (0, _toolkit.startLocalDaemon)((0, _toolkit.getBinaryPath)(), (0, _toolkit.getDefaultRepoPath)(), {
        detached: false
      });
    }
  }, {
    title: `Fetching ${(0, _chalk.bold)(apmRepoName)}@${apmRepoVersion}`,
    skip: ctx => ctx.repo,
    // only run if repo isn't passed
    task: async ctx => {
      const progressHandler = step => {
        switch (step) {
          case 1:
            console.log(`Initialize aragonPM`);
            break;

          case 2:
            console.log(`Fetching...`);
            break;
        }
      };

      ctx.repo = await (0, _toolkit.getApmRepo)(web3, apmRepoName, apmOptions, apmRepoVersion, progressHandler);
    }
  }, {
    title: 'Upgrading app',
    task: async ctx => {
      const basesNamespace = await (0, _toolkit.getBasesNamespace)(dao, web3);
      return (0, _execHandler.task)({
        dao,
        app: dao,
        method: 'setApp',
        params: [basesNamespace, ctx.repo.appId, ctx.repo.contractAddress],
        reporter,
        gasPrice,
        apm: apmOptions,
        web3,
        wsProvider
      });
    }
  }], (0, _listrOptions.default)(silent, debug));
  return tasks.run().then(ctx => {
    reporter.newLine();
    reporter.success(`Successfully executed: "${(0, _chalk.blue)(ctx.transactionPath.description)}"`);
  });
};

exports.handler = handler;
//# sourceMappingURL=upgrade.js.map