"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.task = exports.builder = exports.arappContract = exports.describe = exports.command = void 0;

var _path = _interopRequireDefault(require("path"));

var _listr = _interopRequireDefault(require("listr"));

var _chalk = require("chalk");

var _truffleRunner = require("../helpers/truffle-runner");

var _web3Fallback = require("../helpers/web3-fallback");

var _truffleDeployArtifacts = _interopRequireDefault(require("../helpers/truffle-deploy-artifacts"));

var _listrOptions = _interopRequireDefault(require("../helpers/listr-options"));

var _util = require("../util");

var _deploy = require("../lib/deploy/deploy");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'deploy [contract]';
exports.command = command;
const describe = 'Deploys contract code of the app to the chain';
exports.describe = describe;

const arappContract = () => {
  const contractPath = require(_path.default.resolve((0, _util.findProjectRoot)(), 'arapp.json')).path;

  const contractName = _path.default.basename(contractPath).split('.')[0];

  return contractName;
};

exports.arappContract = arappContract;

const builder = yargs => {
  return yargs.positional('contract', {
    description: 'Contract name (defaults to the contract at the path in arapp.json)'
  }).option('init', {
    description: 'Arguments to be passed to contract constructor',
    array: true,
    default: []
  });
};

exports.builder = builder;

const task = async ({
  module,
  network,
  gasPrice,
  cwd,
  contract,
  init = [],
  web3,
  apmOptions,
  silent,
  debug
}) => {
  if (!contract) {
    contract = arappContract();
  }

  if (!web3) {
    web3 = await (0, _web3Fallback.ensureWeb3)(network);
  } // Mappings allow to pass certain init parameters that get replaced for their actual value
  // const mappingMask = key => `@ARAGON_${key}`


  const mappings = {
    '@ARAGON_ENS': apmOptions.ensRegistryAddress // <ens> to ens addr

  };
  const initArguments = init.map(value => mappings[value] || value);
  const contractName = contract;
  const tasks = new _listr.default([{
    title: 'Compile contracts',
    task: async () => (0, _truffleRunner.compileContracts)()
  }, {
    title: `Deploy '${contractName}' to network`,
    task: async (ctx, task) => {
      try {
        ctx.contractArtifacts = require(_path.default.join(cwd, 'build/contracts', contractName));
      } catch (e) {
        throw new Error('Contract artifact couldnt be found. Please ensure your contract name is the same as the filename.');
      }

      const {
        bytecode,
        abi
      } = ctx.contractArtifacts || {};
      const {
        links
      } = (module || {}).env || {};

      if (!bytecode || bytecode === '0x') {
        throw new Error('Contract bytecode couldnt be generated. Contracts that dont implement all interface methods cant be deployed');
      }

      task.output = `Deploying '${contractName}' to network`;
      const {
        instance,
        address,
        transactionHash
      } = await (0, _deploy.deployContract)({
        bytecode: links ? (0, _deploy.linkLibraries)(bytecode, links) : bytecode,
        abi,
        initArguments,
        gasPrice: network.gasPrice || gasPrice,
        web3
      });

      if (!address) {
        throw new Error('Contract deployment failed');
      }

      ctx.contractInstance = instance;
      ctx.contractName = contractName;
      ctx.contractAddress = address;
      ctx.transactionHash = transactionHash;
    }
  }, {
    title: 'Generate deployment artifacts',
    task: async ctx => {
      ctx.deployArtifacts = await (0, _truffleDeployArtifacts.default)(ctx.contractArtifacts);
      ctx.deployArtifacts.transactionHash = ctx.transactionHash;
    }
  }], (0, _listrOptions.default)(silent, debug));
  return tasks;
};

exports.task = task;

const handler = async ({
  module,
  reporter,
  gasPrice,
  network,
  cwd,
  contract,
  init,
  apm: apmOptions,
  silent,
  debug
}) => {
  reporter.warning('This command is deprecated and will be removed in a future release. Please see the Aragon Buidler plugin for an improved development experience: https://github.com/aragon/buidler-aragon');
  const tasks = await task({
    module,
    reporter,
    gasPrice,
    network,
    cwd,
    contract,
    init,
    apmOptions,
    silent,
    debug
  });
  const ctx = await tasks.run();
  reporter.success(`Successfully deployed ${(0, _chalk.blue)(ctx.contractName)} at: ${(0, _chalk.green)(ctx.contractAddress)}`);
  reporter.info(`Transaction hash: ${(0, _chalk.blue)(ctx.transactionHash)}`);
};

exports.handler = handler;
//# sourceMappingURL=deploy.js.map