"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.task = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _chalk = require("chalk");

var _execa = _interopRequireDefault(require("execa"));

var _findProcess = _interopRequireDefault(require("find-process"));

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../../helpers/listr-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'status';
exports.command = command;
const describe = 'Status of the local devchain.';
exports.describe = describe;

const builder = yargs => {
  return yargs.option('port', {
    description: 'The port to check',
    default: 8545
  });
};

exports.builder = builder;

const task = async ({
  port,
  reset,
  silent,
  debug
}) => {
  return new _listr.default([{
    title: 'Check port',
    task: async ctx => {
      ctx.portTaken = await (0, _toolkit.isPortTaken)(port);

      if (ctx.portTaken) {
        const processData = await (0, _findProcess.default)('port', port);
        ctx.processID = processData[0].pid;
      }
    }
  }, {
    title: 'Kill running process',
    enabled: ctx => ctx.portTaken && reset,
    task: async ctx => {
      await (0, _execa.default)('kill', [ctx.processID]);
      return `Process running at port ${(0, _chalk.blue)(port)} was killed.`;
    }
  }], (0, _listrOptions.default)(silent, debug));
};

exports.task = task;

const handler = async function ({
  port,
  reset = false,
  reporter,
  debug,
  silent
}) {
  const tasks = await task({
    port,
    reset,
    reporter,
    debug,
    silent
  });
  const {
    portTaken,
    processID
  } = await tasks.run();
  reporter.newLine();

  if (portTaken && !reset) {
    reporter.info(`Devchain running at port: ${(0, _chalk.blue)(port)}`);
    reporter.info(`Process ID: ${(0, _chalk.blue)(processID)}`);
  } else if (!reset) {
    reporter.info(`Devchain is not running at port: ${(0, _chalk.blue)(port)}`);
  }

  reporter.newLine();
};

exports.handler = handler;
//# sourceMappingURL=status.js.map