"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _path = _interopRequireDefault(require("path"));

var _chalk = require("chalk");

var _listr = _interopRequireDefault(require("listr"));

var _toolkit = require("@aragon/toolkit");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const command = 'extract-functions [contract]';
exports.command = command;
const describe = 'Extract function information from a Solidity file';
exports.describe = describe;

const builder = function (yargs) {
  return yargs.positional('contract', {
    description: 'Path to the Solidity file to extract functions from',
    type: 'string'
  }).option('output', {
    description: 'Path of the directory where the output file will be saved to',
    type: 'string',
    default: '.'
  });
};

exports.builder = builder;

const handler = async function ({
  cwd,
  reporter,
  contract,
  output
}) {
  let outputPath;
  const tasks = new _listr.default([{
    title: 'Extracting functions',
    task: async () => {
      const contractPath = _path.default.resolve(cwd, contract);

      const filename = _path.default.basename(contractPath).replace('.sol', '.json');

      outputPath = _path.default.resolve(output, filename);
      await (0, _toolkit.extractContractInfoToFile)(contractPath, outputPath);
    }
  }]);
  await tasks.run();
  reporter.success(`Saved to ${(0, _chalk.blue)(outputPath)}`);
};

exports.handler = handler;
//# sourceMappingURL=extract-functions.js.map