"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../../helpers/listr-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'start';
exports.command = command;
const describe = 'Start and configure the daemon.';
exports.describe = describe;
const DETACH_ALIAS = 'D';

const builder = yargs => yargs.option('bin-path', {
  description: 'The location of the IPFS binary',
  default: (0, _toolkit.getBinaryPath)()
}).option('repo-path', {
  description: 'The location of the IPFS repository',
  default: (0, _toolkit.getDefaultRepoPath)()
}).option('api-port', {
  default: 5001
}).option('gateway-port', {
  // todo number:true
  default: 8080
}).option('swarm-port', {
  default: 4001
}).option('detached', {
  description: 'Whether to run the daemon in the background',
  // uppercase D to avoid conflicting with --debug
  alias: DETACH_ALIAS,
  default: false,
  boolean: true
});

exports.builder = builder;

const runStartTask = ({
  binPath,
  repoPath,
  apiPort,
  gatewayPort,
  swarmPort,
  detached,
  silent,
  debug
}) => {
  return new _listr.default([{
    title: 'Checking repository',
    task: async () => {
      await (0, _toolkit.ensureRepoInitialized)(binPath, repoPath);
    }
  }, {
    title: 'Configure ports',
    task: async () => {
      await (0, _toolkit.setPorts)(repoPath, apiPort, gatewayPort, swarmPort);
    }
  }, {
    title: 'Start the daemon',
    task: async ctx => {
      ctx.processController = await (0, _toolkit.startLocalDaemon)(binPath, repoPath, {
        detached
      });
    }
  }], (0, _listrOptions.default)(silent, debug)).run();
};

const handler = async argv => {
  const {
    binPath,
    repoPath,
    apiPort,
    gatewayPort,
    swarmPort,
    detached,
    silent,
    debug,
    reporter
  } = argv;
  const {
    processController
  } = await runStartTask({
    binPath,
    repoPath,
    apiPort,
    gatewayPort,
    swarmPort,
    detached,
    silent,
    debug
  });
  reporter.newLine();

  if (!detached) {
    processController.attach();
    reporter.info(`Did you know you can run the IPFS Daemon in the background using the '-${DETACH_ALIAS}' option?`);
  } // if (detached && !processController) {
  //   reporter.warning('The IPFS Daemon is already running on these ports!')
  //   reporter.warning('Trying to connect to the existing process...')
  // }


  if (detached) {
    reporter.info(`Daemon output:\n${processController.output}`);
    processController.detach();
    reporter.warning('The IPFS Daemon will continue running in the background!');
    reporter.warning('Use the `aragon ipfs stop` command to stop it.');
  }
  /**
   * Configure IPFS with Aragon-specific logic
   */


  const httpClient = await (0, _toolkit.getHttpClient)(`http://localhost:${apiPort}`);
  await (0, _toolkit.configureCors)(httpClient);
  reporter.success('Successfully configured CORS');
  const hashes = await (0, _toolkit.pinArtifacts)(httpClient);
  reporter.success(`Successfully pinned ${hashes.length} Aragon artifacts.`);

  if (!detached) {
    // Patch to prevent calling the onFinishCommand hook
    await new Promise((resolve, reject) => {});
  }
};

exports.handler = handler;
//# sourceMappingURL=start.js.map