"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../../helpers/listr-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'stop';
exports.command = command;
const describe = 'Stop the daemon.';
exports.describe = describe;

const builder = yargs => yargs.option('repo-path', {
  description: 'The location of the IPFS repository',
  default: (0, _toolkit.getDefaultRepoPath)()
});

exports.builder = builder;

const runStartTask = ({
  repoPath,
  silent,
  debug
}) => {
  return new _listr.default([{
    title: 'Find ports',
    task: async ctx => {
      ctx.repo = await (0, _toolkit.getRepoConfig)(repoPath);
      ctx.ports = await (0, _toolkit.getPorts)(ctx.repo);
    }
  }, {
    title: 'Check ports',
    task: async ctx => {
      try {
        // isPortTaken
        await (0, _toolkit.getHttpClient)(`http://localhost:${ctx.ports.api}`);
      } catch (err) {
        throw new Error('The IPFS Daemon is already stopped');
      }
    }
  }, {
    title: 'Kill the process',
    task: async ctx => {
      await (0, _toolkit.killProcessOnPort)(ctx.ports.api);
    }
  }], (0, _listrOptions.default)(silent, debug)).run();
};

const handler = async argv => {
  const {
    reporter,
    silent,
    debug,
    repoPath
  } = argv;
  await runStartTask({
    silent,
    debug,
    repoPath
  });
  reporter.success('The IPFS Daemon stopped successfully');
};

exports.handler = handler;
//# sourceMappingURL=stop.js.map