"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _execa = _interopRequireDefault(require("execa"));

var _inquirer = _interopRequireDefault(require("inquirer"));

var _chalk = require("chalk");

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../../helpers/listr-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'uninstall';
exports.command = command;
const describe = 'Uninstall the go-ipfs binaries.';
exports.describe = describe;

const builder = yargs => yargs.option('local', {
  description: 'Whether to uninstall IPFS from the project dependencies',
  boolean: true,
  default: false
}).option('skip-confirmation', {
  description: 'Whether to skip the confirmation step',
  boolean: true,
  default: false
});

exports.builder = builder;

const runUninstallTask = ({
  silent,
  debug,
  local
}) => {
  return new _listr.default([{
    title: 'Uninstall IPFS',
    task: async task => {
      const npmBinary = (0, _toolkit.getNodePackageManager)();
      const npmArgs = ['uninstall', 'go-ipfs'];

      if (!local) {
        npmArgs.push('--global');
      }

      const logPrefix = `npm ${npmArgs.join(' ')}:`;
      const uninstallProcess = (0, _execa.default)(npmBinary, npmArgs);
      uninstallProcess.stdout.on('data', log => {
        if (log) task.output = `${logPrefix} ${log}`;
      });
      await uninstallProcess;
    }
  }], (0, _listrOptions.default)(silent, debug)).run();
};

const handler = async argv => {
  const {
    debug,
    silent,
    skipConfirmation,
    local,
    reporter
  } = argv;
  /**
   * Check if it's installed
   */

  const ipfsBinPath = local ? (0, _toolkit.getLocalBinary)('ipfs', process.cwd()) : (0, _toolkit.getGlobalBinary)('ipfs');

  if (!ipfsBinPath) {
    throw Error('IPFS is not installed');
  }
  /**
   * Print confirmation details
   */


  reporter.info(`Location: ${(0, _chalk.blue)(ipfsBinPath)}`);
  /**
   * Confirm & uninstall
   */

  reporter.newLine();

  if (!skipConfirmation) {
    const {
      confirmation
    } = await _inquirer.default.prompt([{
      type: 'confirm',
      name: 'confirmation',
      default: false,
      message: `Are you sure you want to ${(0, _chalk.red)('uninstall IPFS')}?`
    }]);
    if (!confirmation) return;
  }

  await runUninstallTask({
    silent,
    debug,
    local
  });
  reporter.newLine();
  reporter.success('Success!');
};

exports.handler = handler;
//# sourceMappingURL=uninstall.js.map