"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _chalk = require("chalk");

var _isIpfs = require("is-ipfs");

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../../helpers/listr-options"));

var _util = require("../../util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const command = 'view [cid]';
exports.command = command;
const describe = 'Show metadata about the content: size, links, etc. Uses --ipfs-gateway.';
exports.describe = describe;

const builder = yargs => yargs.positional('cid', {
  // TODO add support for "ipfs paths", e.g: QmP49YSJVhQTySqLDFTzFZPG8atf3CLsQSPDVj3iATQkhC/arapp.json
  description: 'A self-describing content-addressed identifier'
});

exports.builder = builder;

const runViewTask = ({
  cid,
  ipfsReader,
  silent,
  debug
}) => {
  return new _listr.default([{
    title: 'Start IPFS',
    skip: async () => (0, _toolkit.isLocalDaemonRunning)(),
    task: async () => {
      await (0, _toolkit.startLocalDaemon)((0, _toolkit.getBinaryPath)(), (0, _toolkit.getDefaultRepoPath)(), {
        detached: false
      });
    }
  }, {
    title: 'Validate CID',
    task: () => {
      if (!(0, _isIpfs.cid)(cid)) {
        throw new Error(`"${cid}" is not a valid content identifier.`);
      }
    }
  }, {
    title: 'Fetch the links',
    task: async (ctx, task) => {
      const handleProgress = (step, data) => {
        switch (step) {
          case 1:
            task.output = `Fetch DAG information for ${(0, _chalk.gray)(data)}`;
            break;

          case 2:
            task.output = `Parse DAG information for ${(0, _chalk.gray)(data)}`;
            break;
        }
      };

      ctx.merkleDAG = await (0, _toolkit.getMerkleDAG)(ipfsReader, cid, {
        recursive: true,
        progressCallback: handleProgress
      });
    }
  }], (0, _listrOptions.default)(silent, debug)).run();
};

const handler = async argv => {
  /**
   * Interactive input
   */
  let {
    cid
  } = argv;

  if (!cid) {
    cid = await (0, _util.askForInput)('Choose a content identifier');
  }

  const {
    reporter,
    apm,
    debug,
    silent
  } = argv;
  const ipfsReader = await (0, _toolkit.getHttpClient)(apm.ipfs.gateway);
  const ctx = await runViewTask({
    cid,
    ipfsReader,
    reporter,
    debug,
    silent
  }); // reporter.message(stringifyMerkleDAG(ctx.merkleDAG))

  console.log((0, _toolkit.stringifyMerkleDAG)(ctx.merkleDAG));
};

exports.handler = handler;
//# sourceMappingURL=view.js.map