"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.builder = exports.describe = exports.command = void 0;

var _listr = _interopRequireDefault(require("listr"));

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _url = _interopRequireDefault(require("url"));

var _web = _interopRequireDefault(require("web3"));

var _chalk = require("chalk");

var _apm = _interopRequireDefault(require("@aragon/apm"));

var _toolkit = require("@aragon/toolkit");

var _listrOptions = _interopRequireDefault(require("../helpers/listr-options"));

var _package = _interopRequireDefault(require("../../package.json"));

var _util = require("../util");

var _getRepoTask = require("./apm_cmds/util/getRepoTask");

var _runPrepareForPublishTask = _interopRequireDefault(require("./apm_cmds/util/runPrepareForPublishTask"));

var _start = require("./devchain_cmds/start");

var _start2 = require("./start");

var _deploy = require("./deploy");

var _publish = require("./apm_cmds/publish");

var _runPublishTask = _interopRequireDefault(require("./apm_cmds/util/runPublishTask"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
// cmds
const DEFAULT_CLIENT_REPO = _package.default.aragon.clientRepo;
const DEFAULT_CLIENT_VERSION = _package.default.aragon.clientVersion;
const DEFAULT_CLIENT_PORT = _package.default.aragon.clientPort;
const BARE_TEMPLATE = (0, _toolkit.defaultAPMName)('bare-template');
const BARE_INSTANCE_FUNCTION = 'newInstance';
const BARE_TEMPLATE_DEPLOY_EVENT = 'DeployDao';
const command = 'run';
exports.command = command;
const describe = 'Run the current app locally';
exports.describe = describe;

const builder = function (yargs) {
  return yargs.option('client', {
    description: 'Just run the smart contracts, without the Aragon client',
    default: true,
    boolean: true
  }).option('files', {
    description: 'Path(s) to directories containing files to publish. Specify multiple times to include multiple files.',
    default: ['.'],
    array: true
  }).option('port', {
    description: 'Port to start devchain at',
    default: '8545'
  }).option('network-id', {
    description: 'Network id to connect with'
  }).option('hardfork', {
    description: 'Allows to specify which hardfork should be used. Supported hardforks are byzantium, constantinople, petersburg, and istanbul (default).'
  }).option('block-time', {
    description: 'Specify blockTime in seconds for automatic mining'
  }).option('accounts', {
    default: 2,
    description: 'Number of accounts to print'
  }).option('reset', {
    default: false,
    boolean: true,
    description: 'Reset devchain to snapshot'
  }).option('template', {
    default: BARE_TEMPLATE,
    description: 'Template contract name'
  }).option('template-init', {
    description: 'Arguments to be passed to the template constructor',
    array: true,
    default: []
  }).option('template-deploy-event', {
    description: 'Event name that the template will fire on success',
    default: BARE_TEMPLATE_DEPLOY_EVENT
  }).option('template-new-instance', {
    description: 'Function to be called to create template instance',
    default: BARE_INSTANCE_FUNCTION
  }).option('template-args', {
    description: 'Arguments to be passed to the function specified in --template-new-instance',
    array: true,
    default: [],
    coerce: args => {
      return args.map(_util.parseArgumentStringIfPossible);
    }
  }).option('build', {
    description: 'Whether publish should try to build the app before publishing, running the script specified in --build-script',
    default: true,
    boolean: true
  }).option('build-script', {
    description: 'The npm script that will be run when building the app',
    default: 'build'
  }).option('publish-dir', {
    description: 'Temporary directory where files will be copied before publishing. Defaults to temp dir.',
    default: null
  }).option('prepublish', {
    description: 'Whether publish should run prepublish script specified in --prepublish-script before publishing',
    default: false,
    boolean: true
  }).option('prepublish-script', {
    description: 'The npm script that will be run before publishing the app',
    default: 'prepublishOnly'
  }).option('bump', {
    description: 'Type of bump (major, minor or patch) or version number to publish the app',
    type: 'string',
    default: 'major'
  }).option('http', {
    description: 'URL for where your app is served from e.g. localhost:1234',
    default: null,
    coerce: url => {
      return url && url.substr(0, 7) !== 'http://' ? `http://${url}` : url;
    }
  }).option('http-served-from', {
    description: 'Directory where your files is being served from e.g. ./dist',
    default: null
  }).option('app-init', {
    description: 'Name of the function that will be called to initialize an app',
    default: 'initialize'
  }).option('app-init-args', {
    description: 'Arguments for calling the app init function',
    array: true,
    default: []
  }).option('client-repo', {
    description: 'Repo of Aragon client used to run your sandboxed app',
    default: DEFAULT_CLIENT_REPO
  }).option('client-version', {
    description: 'Version of Aragon client used to run your sandboxed app',
    default: DEFAULT_CLIENT_VERSION
  }).option('client-port', {
    description: 'Port being used by Aragon client',
    default: DEFAULT_CLIENT_PORT
  }).option('client-path', {
    description: 'A path pointing to an existing Aragon client installation',
    default: null
  });
};

exports.builder = builder;

const handler = async function ({
  // Globals
  reporter,
  gasPrice,
  cwd,
  apm: apmOptions,
  silent,
  debug,
  network,
  module,
  client,
  files,
  port,
  networkId,
  hardfork,
  blockTime,
  accounts,
  reset,
  template,
  templateInit,
  templateDeployEvent,
  templateNewInstance,
  templateArgs,
  build,
  buildScript,
  publishDir,
  prepublish,
  prepublishScript,
  bump,
  http,
  httpServedFrom,
  appInit,
  appInitArgs,
  clientRepo,
  clientVersion,
  clientPort,
  clientPath
}) {
  reporter.warning('This command is deprecated and will be removed in a future release. Please see the Aragon Buidler plugin for an improved development experience: https://github.com/aragon/buidler-aragon');

  if (http && !(await (0, _util.isHttpServerOpen)(http))) {
    throw Error(`Can't connect to ${http}, make sure the http server is running.`);
  } // Set prepublish to true if --prepublish-script argument is used


  if (process.argv.includes('--prepublish-script')) prepublish = true;
  const showAccounts = accounts;
  const tasks = new _listr.default([{
    title: 'Start IPFS',
    skip: async () => (0, _toolkit.isLocalDaemonRunning)(),
    task: async () => {
      await (0, _toolkit.startLocalDaemon)((0, _toolkit.getBinaryPath)(), (0, _toolkit.getDefaultRepoPath)(), {
        detached: false
      });
    }
  }, {
    title: 'Start a local Ethereum network',
    skip: async ctx => {
      const hostURL = new _url.default.URL(network.provider.connection._url);

      if (!(await (0, _toolkit.isPortTaken)(hostURL.port))) {
        return false;
      } else {
        ctx.web3 = new _web.default(network.provider);
        ctx.accounts = await ctx.web3.eth.getAccounts();
        return 'Connected to the provided Ethereum network';
      }
    },
    task: async (ctx, task) => (0, _start.task)({
      port,
      networkId,
      hardfork,
      blockTime,
      reset,
      showAccounts
    })
  }, {
    title: 'Setup before publish',
    task: async ctx => {
      ctx.publishParams = {
        provider: 'ipfs',
        files,
        ignore: ['node_modules'],
        reporter,
        debug,
        silent,
        gasPrice,
        cwd,
        network,
        module,
        buildScript,
        build,
        publishDir,
        prepublishScript,
        prepublish,
        contract: (0, _deploy.arappContract)(),
        web3: ctx.web3,
        apm: apmOptions,
        bump,
        http,
        httpServedFrom
      };
      return (0, _publish.setupTask)(ctx.publishParams);
    }
  }, {
    title: 'Prepare for publish',
    task: async ctx => (0, _runPrepareForPublishTask.default)({ ...ctx.publishParams,
      module,
      // context
      initialRepo: ctx.initialRepo,
      initialVersion: ctx.initialVersion,
      version: ctx.version,
      contractAddress: ctx.contract,
      deployArtifacts: ctx.deployArtifacts
    })
  }, {
    title: 'Publish app to aragonPM',
    task: async ctx => {
      const {
        dao,
        proxyAddress,
        methodName,
        params
      } = ctx.intent;
      return (0, _runPublishTask.default)({ ...ctx.publishParams,
        // context
        version: ctx.version,
        contractAddress: ctx.contract,
        pathToPublish: ctx.pathToPublish,
        dao,
        proxyAddress,
        methodName,
        params
      });
    }
  }, {
    title: 'Fetch published repo',
    task: async ctx => (0, _getRepoTask.task)({
      apmRepo: module.appName,
      apm: (0, _apm.default)(ctx.web3, apmOptions),
      artifactRequired: false
    })
  }, {
    title: 'Deploy Template',
    enabled: () => template !== BARE_TEMPLATE,
    task: ctx => {
      const deployParams = {
        module,
        contract: template,
        init: templateInit,
        reporter,
        gasPrice,
        network,
        cwd,
        web3: ctx.web3,
        apmOptions
      };
      return (0, _deploy.task)(deployParams);
    }
  }, {
    title: `Fetching template ${(0, _chalk.bold)(template)}@latest`,
    task: async ctx => {
      ctx.template = await (0, _toolkit.getApmRepo)(ctx.web3, template, apmOptions, 'latest');
    },
    enabled: ctx => !ctx.contractInstance
  }, {
    title: 'Create Organization from template',
    task: async ctx => {
      const roles = ctx.repo.roles || [];
      const rolesBytes = roles.map(role => role.bytes);
      let fnArgs;

      if (ctx.contractInstance) {
        // If template was deployed, use template args
        fnArgs = templateArgs;
      } else {
        // TODO: Report warning when app wasn't initialized
        const initPayload = (0, _toolkit.encodeInitPayload)(ctx.web3, ctx.repo.abi, appInit, appInitArgs);

        if (initPayload === '0x') {
          ctx.notInitialized = true;
        }

        fnArgs = [ctx.repo.appId || ctx.repo.environments.default.appId, rolesBytes, ctx.accounts[0], initPayload];
      }

      ctx.daoAddress = await (0, _toolkit.newDao)({
        repo: ctx.template,
        web3: ctx.web3,
        templateInstance: ctx.contractInstance,
        newInstanceMethod: templateNewInstance,
        newInstanceArgs: fnArgs,
        deployEvent: templateDeployEvent,
        gasPrice
      });
    }
  }, {
    title: 'Start Client',
    enabled: () => client === true,
    task: async (ctx, task) => (0, _start2.task)({
      clientRepo,
      clientVersion,
      clientPort,
      clientPath
    })
  }], (0, _listrOptions.default)(silent, debug));

  const manifestPath = _path.default.resolve((0, _util.findProjectRoot)(), 'manifest.json');

  let manifest;

  if (_fsExtra.default.existsSync(manifestPath)) {
    manifest = _fsExtra.default.readJsonSync(manifestPath);
  }

  return tasks.run({
    ens: apmOptions.ensRegistryAddress
  }).then(async ctx => {
    if (ctx.portOpen) {
      reporter.warning(`The server already listening at port ${(0, _chalk.blue)(clientPort)}, skipped starting Aragon.`);
    }

    if (ctx.notInitialized) {
      reporter.warning('The app could not be initialized, check the --app-init flag. Functions protected behind the ACL will not work until the app is initialized.');
    }

    if (files.length === 1 && _path.default.normalize(files[0]) === '.') {
      reporter.warning(`Publishing files from the project's root folder is not recommended. Consider using the distribution folder of your project: "--files <folder>".`);
    }

    reporter.newLine();
    reporter.info(`You are now ready to open your app in Aragon.`);
    reporter.newLine();

    if (ctx.privateKeys) {
      (0, _start.printAccounts)(reporter, ctx.privateKeys);
    }

    if (ctx.mnemonic) {
      (0, _start.printMnemonic)(reporter, ctx.mnemonic);
    }

    (0, _start.printResetNotice)(reporter, reset);
    const registry = module.appName.split('.').slice(1).join('.');
    reporter.info(`This is the configuration for your development deployment:
    ${'Ethereum Node'}: ${(0, _chalk.blue)(network.provider.connection._url)}
    ${'ENS registry'}: ${(0, _chalk.blue)(ctx.ens)}
    ${`aragonPM registry`}: ${(0, _chalk.blue)(registry)}
    ${'Organization address'}: ${(0, _chalk.green)(ctx.daoAddress)}`);
    reporter.newLine();
    reporter.info(`${client !== false ? `Open ${(0, _chalk.bold)(`http://localhost:${clientPort}/#/${ctx.daoAddress}`)} to view your DAO` : `Use ${(0, _chalk.bold)(`"aragon dao <command> ${ctx.daoAddress}"`)} to interact with your Organization`}`);

    if (!manifest) {
      reporter.warning('No front-end detected (no manifest.json)');
    } else if (!manifest.start_url) {
      reporter.warning('No front-end detected (no start_url defined)');
    } // Patch to prevent calling the onFinishCommand hook


    await new Promise((resolve, reject) => {});
  });
};

exports.handler = handler;
//# sourceMappingURL=run.js.map