"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handler = exports.task = exports.builder = exports.describe = exports.command = void 0;

var _chalk = require("chalk");

var _listr = _interopRequireDefault(require("listr"));

var _start = require("../lib/start");

var _toolkit = require("@aragon/toolkit");

var _package = _interopRequireDefault(require("../../package.json"));

var _util = require("../util");

var _listrOptions = _interopRequireDefault(require("../helpers/listr-options"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const DEFAULT_CLIENT_REPO = _package.default.aragon.clientRepo;
const DEFAULT_CLIENT_VERSION = _package.default.aragon.clientVersion;
const DEFAULT_CLIENT_PORT = _package.default.aragon.clientPort;
const command = 'start [client-repo] [client-version]';
exports.command = command;
const describe = 'Start the Aragon GUI (graphical user interface)';
exports.describe = describe;

const builder = yargs => {
  return yargs.positional('client-repo', {
    description: 'Repo of Aragon client used to run your sandboxed app (valid git repository using https or ssh protocol)',
    default: DEFAULT_CLIENT_REPO
  }).positional('client-version', {
    description: 'Version of Aragon client used to run your sandboxed app (commit hash, branch name or tag name)',
    default: DEFAULT_CLIENT_VERSION
  }).option('client-port', {
    description: 'Port being used by Aragon client',
    default: DEFAULT_CLIENT_PORT
  }).option('client-path', {
    description: 'A path pointing to an existing Aragon client installation',
    default: null
  }).option('auto-open', {
    description: 'Wether to automatically open the client in the browser',
    boolean: true,
    default: true
  });
};

exports.builder = builder;

const task = async function ({
  clientRepo,
  clientVersion,
  clientPort,
  clientPath,
  autoOpen,
  silent,
  debug
}) {
  const tasks = new _listr.default([{
    title: 'Fetching client from aragen',
    skip: () => !!clientPath,
    task: async (ctx, task) => {
      task.output = 'Fetching client...';
      await (0, _start.fetchClient)(ctx, task, DEFAULT_CLIENT_VERSION);
    },
    enabled: () => clientVersion === DEFAULT_CLIENT_VERSION
  }, {
    title: 'Downloading client',
    skip: ctx => !!clientPath,
    task: async (ctx, task) => {
      task.output = 'Downloading client...';
      await (0, _start.downloadClient)({
        ctx,
        task,
        clientRepo,
        clientVersion
      });
    },
    enabled: ctx => !ctx.clientFetch
  }, {
    title: 'Installing client dependencies',
    task: async (ctx, task) => (0, _util.installDeps)(ctx.clientPath, task),
    enabled: ctx => !ctx.clientAvailable && !clientPath
  }, {
    title: 'Building Aragon client',
    task: async (ctx, task) => {
      task.output = 'Building Aragon client...';
      await (0, _start.buildClient)(ctx, clientPath);
    },
    enabled: ctx => !ctx.clientAvailable
  }, {
    title: 'Start IPFS',
    skip: async () => (0, _toolkit.isLocalDaemonRunning)(),
    task: async () => {
      await (0, _toolkit.startLocalDaemon)((0, _toolkit.getBinaryPath)(), (0, _toolkit.getDefaultRepoPath)(), {
        detached: false
      });
    }
  }, {
    title: 'Starting Aragon client',
    task: async (ctx, task) => {
      task.output = 'Starting Aragon client...';
      await (0, _start.startClient)(ctx, clientPort, clientPath);
    }
  }, {
    title: 'Opening client',
    task: async (ctx, task) => {
      if (autoOpen === true) {
        task.output = 'Opening client';
        await (0, _start.openClient)(ctx, clientPort);
      }
    }
  }], (0, _listrOptions.default)(silent, debug));
  return tasks;
};

exports.task = task;

const handler = async ({
  reporter,
  clientRepo,
  clientVersion,
  clientPort,
  clientPath,
  autoOpen,
  silent,
  debug
}) => {
  const tasks = await task({
    clientRepo,
    clientVersion,
    clientPort,
    clientPath,
    autoOpen,
    silent,
    debug
  });
  await tasks.run();
  reporter.info(`Aragon client from ${(0, _chalk.blue)(clientRepo)} version ${(0, _chalk.blue)(clientVersion)} started on port ${(0, _chalk.blue)(clientPort)}`); // Patch to prevent calling the onFinishCommand hook

  await new Promise((resolve, reject) => {});
};

exports.handler = handler;
//# sourceMappingURL=start.js.map