"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ensureDevchain = void 0;

var _path = _interopRequireDefault(require("path"));

var _node = require("@aragon/toolkit/dist/node");

var _constants = require("../commands/devchain_cmds/utils/constants");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//
const ensureDevchain = async ({
  port,
  logger = _node.noop,
  reset
}) => {
  if (await (0, _node.isPortTaken)(port)) {
    logger(`Devchain already started on: ${port}`);
    return;
  }

  const binPath = _path.default.resolve(__dirname, '../index.js');

  logger(`Devchain starting on: ${port}`);

  try {
    const {
      detach
    } = await (0, _node.startProcess)({
      cmd: 'node',
      args: [binPath, 'devchain', '--port', port].concat(reset ? ['--reset'] : []),
      readyOutput: 'Devchain running at',
      execaOpts: {
        detached: true
      },
      timeout: _constants.DEVCHAIN_START_TIMEOUT
    });
    console.log();
    logger(`Devchain started on: ${port}`);
    logger('Devchain ready!!');
    detach();
  } catch (err) {
    logger('Devchain failed to start...');
    logger(`Error: ${err}`);
  }
};

exports.ensureDevchain = ensureDevchain;
//# sourceMappingURL=ensureDevchain.js.map