"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.compileContracts = exports.runTruffle = void 0;

var _execa = _interopRequireDefault(require("execa"));

var _devNull = _interopRequireDefault(require("dev-null"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const runTruffle = (args, {
  stdout,
  stderr,
  stdin
}) => {
  return new Promise((resolve, reject) => {
    const truffle = (0, _execa.default)('truffle', args, {
      preferLocal: true
    });
    let errMsg = '';
    truffle.on('exit', code => {
      code === 0 ? resolve() : reject(errMsg);
    }); // errMsg is only used if the process fails

    truffle.stdout.on('data', err => {
      errMsg += err;
    });
    truffle.stdout.pipe(stdout || process.stdout);
    truffle.stderr.pipe(stderr || process.stderr);
    process.stdin.pipe(stdin || truffle.stdin);
  });
};

exports.runTruffle = runTruffle;

const compileContracts = async () => {
  await runTruffle(['compile'], {
    stdout: (0, _devNull.default)()
  });
};

exports.compileContracts = compileContracts;
//# sourceMappingURL=truffle-runner.js.map