"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.prepareFilesForPublishing = prepareFilesForPublishing;

var _path = _interopRequireDefault(require("path"));

var _ignore = _interopRequireDefault(require("ignore"));

var _fs = _interopRequireDefault(require("fs"));

var _fsExtra = require("fs-extra");

var _util = require("util");

var _toolkit = require("@aragon/toolkit");

var _util2 = require("../../util");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

//

/**
 * Moves the specified files to a temporary directory and returns the path to
 * the temporary directory.
 * @param {string} tmpDir Temporary directory
 * @param {Array<string>} files An array of file paths to include
 * @param {string} ignorePatterns An array of glob-like pattern of files to ignore
 * @return {Promise<string>} The path to the temporary directory
 */
async function prepareFilesForPublishing(tmpDir, files = [], ignorePatterns = null) {
  // Ignored files filter
  const filter = (0, _ignore.default)().add(ignorePatterns);
  const projectRoot = (0, _util2.findProjectRoot)();

  const ipfsignorePath = _path.default.resolve(projectRoot, '.ipfsignore');

  if ((0, _fsExtra.pathExistsSync)(ipfsignorePath)) {
    const ipfsignoreFile = _fs.default.readFileSync(ipfsignorePath).toString();

    filter.add(ipfsignoreFile);
  } else {
    const gitignorePath = _path.default.resolve(projectRoot, '.gitignore');

    if ((0, _fsExtra.pathExistsSync)(gitignorePath)) {
      const gitignoreFile = _fs.default.readFileSync(gitignorePath).toString();

      filter.add(gitignoreFile);
    }
  }

  function filterIgnoredFiles(src) {
    const relativeSrc = _path.default.relative(projectRoot, src);

    return relativeSrc === '' ? true : !filter.ignores(relativeSrc);
  } // Copy files


  await Promise.all(files.map(async file => {
    const stats = await (0, _util.promisify)(_fs.default.lstat)(file);
    let destination = tmpDir;

    if (stats.isFile()) {
      destination = _path.default.resolve(tmpDir, file);
    } // check files are not ignored


    if (filter.ignores(file)) filter.add(`!${file}`);
    if (filter.ignores(file + '/')) filter.add(`!${file}/`);
    return (0, _fsExtra.copy)(file, destination, {
      filter: filterIgnoredFiles
    });
  }));

  const manifestOrigin = _path.default.resolve(projectRoot, _toolkit.MANIFEST_FILE);

  const manifestDst = _path.default.resolve(tmpDir, _toolkit.MANIFEST_FILE);

  if (!(0, _fsExtra.pathExistsSync)(manifestDst) && (0, _fsExtra.pathExistsSync)(manifestOrigin)) {
    await (0, _fsExtra.copy)(manifestOrigin, manifestDst);
  }

  const artifactOrigin = _path.default.resolve(projectRoot, _toolkit.ARTIFACT_FILE);

  const artifactDst = _path.default.resolve(tmpDir, _toolkit.ARTIFACT_FILE);

  if (!(0, _fsExtra.pathExistsSync)(artifactDst) && (0, _fsExtra.pathExistsSync)(artifactOrigin)) {
    await (0, _fsExtra.copy)(artifactOrigin, artifactDst);
  }

  return tmpDir;
}
//# sourceMappingURL=preprareFiles.js.map