"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.configCliMiddleware = configCliMiddleware;

var _truffleConfig = require("../helpers/truffle-config");

var _loadConfigFiles = require("../lib/environment/loadConfigFiles");

var _configEnvironment = require("../lib/environment/configEnvironment");

class InvalidArguments extends Error {}

function configCliMiddleware(argv) {
  const [cmd, subcmd] = argv._;
  const {
    reporter
  } = argv;

  try {
    var _wsProvider$connectio, _wsProvider$connectio2;

    // Load config files
    const manifest = (0, _loadConfigFiles.loadManifestFile)();
    const arapp = (0, _loadConfigFiles.loadArappFile)(); // Configure environment

    if (!arapp) reporter.debug(`Could not find 'arapp.json'. Using the default configuration`);
    const ignoreNetCmd = new Set(['']);
    const ignoreNetSubCmd = new Set(['devchain', 'ipfs']);
    const ignoreNetwork = ignoreNetSubCmd.has(subcmd) || ignoreNetCmd.has(cmd);
    const {
      useFrame,
      environment,
      wsRpc,
      ensRegistry,
      ipfsRpc,
      ipfsGateway
    } = argv;
    const {
      arapp: arappMutated,
      apm: apmMutated,
      network: networkObj,
      wsProvider
    } = (0, _configEnvironment.configEnvironment)({
      ignoreNetwork,
      useFrame,
      environment,
      wsRpc,
      ensRegistry,
      ipfsRpc,
      ipfsGateway,
      arapp,
      truffleConfig: arapp && (0, _truffleConfig.getTruffleConfig)()
    });

    if (wsProvider === null || wsProvider === void 0 ? void 0 : (_wsProvider$connectio = wsProvider.connection) === null || _wsProvider$connectio === void 0 ? void 0 : (_wsProvider$connectio2 = _wsProvider$connectio.url) === null || _wsProvider$connectio2 === void 0 ? void 0 : _wsProvider$connectio2.includes('eth.aragon.network')) {
      reporter.newLine();
      reporter.warning(`The request may take a while because you are connecting to the default node (${wsProvider.connection.url}). For better performance, consider switching to your own Ethereum node or Infura.`, '\n');
      reporter.info(`You have the following options: 
      1. Use the global option "--ws-rpc" (e.g. with wss://mainnet.infura.io/ws/v3/<INFURA_KEY> for Infura)
      2. Set the "wsRPC" field on mainnet environment of the arapp.json`, '\n');
    }

    return {
      manifest,
      module: arappMutated,
      apm: apmMutated,
      network: networkObj,
      wsProvider
    };
  } catch (e) {
    const prettyError = message => {
      reporter.error(message);
      process.exit(1);
    };

    if (e instanceof InvalidArguments) return prettyError(e.message); // Errors from configEnvironment

    if (e instanceof _configEnvironment.NoEnvironmentInArapp) return prettyError(`environment '${e.message}' is not defined in your arapp.json.`);
    if (e instanceof _configEnvironment.NoEnvironmentInDefaults) return prettyError(`Default environment '${e.message}' not found. Try using aragon:local, aragon:rinkeby or aragon:mainnet.`);
    if (e instanceof _configEnvironment.NoNetworkInTruffleConfig) return prettyError(`aragon <command> requires a network '${e.message}' in your truffle.js. For an example, see http://truffleframework.com/docs/advanced/configuration`);
    throw e;
  }
}
//# sourceMappingURL=index.js.map